var a = 2;
function foo() {
    try {
        var a__2 = 1;
        a__2;
    } catch (err__3) {}
    a__2;
}
